@@ -119,20 +119,20 @@ def CORBA_IDL_BNF():
 testnum = 1
 def test( strng ):
     global testnum
-    print strng
+    print(strng)
     try:
         bnf = CORBA_IDL_BNF()
         tokens = bnf.parseString( strng )
-        print "tokens = "
+        print("tokens = ")
         pprint.pprint( tokens.asList() )
         imgname = "idlParse%02d.bmp" % testnum
         testnum += 1
         #~ tree2image.str2image( str(tokens.asList()), imgname )
-    except ParseException, err:
-        print err.line
-        print " "*(err.column-1) + "^"
-        print err
-    print
+    except ParseException as err:
+        print(err.line)
+        print(" "*(err.column-1) + "^")
+        print(err)
+    print()
     
 if __name__ == "__main__":
     test(
